aboutsummaryrefslogtreecommitdiff
path: root/python/pyspark/sql/context.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/pyspark/sql/context.py')
-rw-r--r--python/pyspark/sql/context.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/python/pyspark/sql/context.py b/python/pyspark/sql/context.py
index a271afe4cf..8a1a874884 100644
--- a/python/pyspark/sql/context.py
+++ b/python/pyspark/sql/context.py
@@ -444,13 +444,13 @@ class SQLContext(object):
@property
@since(2.0)
def streams(self):
- """Returns a :class:`ContinuousQueryManager` that allows managing all the
- :class:`ContinuousQuery` ContinuousQueries active on `this` context.
+ """Returns a :class:`StreamingQueryManager` that allows managing all the
+ :class:`StreamingQuery` StreamingQueries active on `this` context.
.. note:: Experimental.
"""
- from pyspark.sql.streaming import ContinuousQueryManager
- return ContinuousQueryManager(self._ssql_ctx.streams())
+ from pyspark.sql.streaming import StreamingQueryManager
+ return StreamingQueryManager(self._ssql_ctx.streams())
class HiveContext(SQLContext):